@@ -44,6 +44,15 @@ def ask_for_year(args):
                                validation_regex=r'^[1-9]\d{3,}$')
 
 
+def ask_for_chassis(args):
+    types = pmb.config.deviceinfo_chassis_types
+
+    logging.info("What type of device is it?")
+    logging.info("Valid types are: " + ", ".join(types))
+    return pmb.helpers.cli.ask(args, "Chassis", None, None, True,
+                               validation_regex='|'.join(types), complete=types)
+
+
 def ask_for_keyboard(args):
     return pmb.helpers.cli.confirm(args, "Does the device have a hardware keyboard?")
 
@@ -105,46 +114,47 @@ def generate_deviceinfo_fastboot_content(args, bootimg=None):
                    "second_offset": "",
                    "tags_offset": "",
                    "pagesize": "2048"}
-    return """\
-        deviceinfo_kernel_cmdline=\"""" + bootimg["cmdline"] + """\"
+    return f"""\
+        deviceinfo_kernel_cmdline="{bootimg["cmdline"]}"
         deviceinfo_generate_bootimg="true"
-        deviceinfo_bootimg_qcdt=\"""" + bootimg["qcdt"] + """\"
-        deviceinfo_bootimg_dtb_second=\"""" + bootimg["dtb_second"] + """\"
-        deviceinfo_flash_offset_base=\"""" + bootimg["base"] + """\"
-        deviceinfo_flash_offset_kernel=\"""" + bootimg["kernel_offset"] + """\"
-        deviceinfo_flash_offset_ramdisk=\"""" + bootimg["ramdisk_offset"] + """\"
-        deviceinfo_flash_offset_second=\"""" + bootimg["second_offset"] + """\"
-        deviceinfo_flash_offset_tags=\"""" + bootimg["tags_offset"] + """\"
-        deviceinfo_flash_pagesize=\"""" + bootimg["pagesize"] + """\"
+        deviceinfo_bootimg_qcdt="{bootimg["qcdt"]}"
+        deviceinfo_bootimg_dtb_second="{bootimg["dtb_second"]}"
+        deviceinfo_flash_offset_base="{bootimg["base"]}"
+        deviceinfo_flash_offset_kernel="{bootimg["kernel_offset"]}"
+        deviceinfo_flash_offset_ramdisk="{bootimg["ramdisk_offset"]}"
+        deviceinfo_flash_offset_second="{bootimg["second_offset"]}"
+        deviceinfo_flash_offset_tags="{bootimg["tags_offset"]}"
+        deviceinfo_flash_pagesize="{bootimg["pagesize"]}"
         """
 
 
 def generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
-                        has_keyboard, has_external_storage,
+                        chassis, has_keyboard, has_external_storage,
                         flash_method, bootimg=None):
     codename = "-".join(pkgname.split("-")[1:])
     # Note: New variables must be added to pmb/config/__init__.py as well
-    content = """\
+    content = f"""\
         # Reference: <https://postmarketos.org/deviceinfo>
         # Please use double quotes only. You can source this file in shell scripts.
 
         deviceinfo_format_version="0"
-        deviceinfo_name=\"""" + name + """\"
-        deviceinfo_manufacturer=\"""" + manufacturer + """\"
-        deviceinfo_codename=\"""" + codename + """\"
-        deviceinfo_year=\"""" + year + """\"
+        deviceinfo_name="{name}"
+        deviceinfo_manufacturer="{manufacturer}"
+        deviceinfo_codename="{codename}"
+        deviceinfo_year="{year}"
         deviceinfo_dtb=""
         deviceinfo_modules_initfs=""
-        deviceinfo_arch=\"""" + arch + """\"
+        deviceinfo_arch="{arch}"
 
         # Device related
-        deviceinfo_keyboard=\"""" + ("true" if has_keyboard else "false") + """\"
-        deviceinfo_external_storage=\"""" + ("true" if has_external_storage else "false") + """\"
+        deviceinfo_chassis="{chassis}"
+        deviceinfo_keyboard="{"true" if has_keyboard else "false"}"
+        deviceinfo_external_storage="{"true" if has_external_storage else "false"}"
         deviceinfo_screen_width="800"
         deviceinfo_screen_height="600"
 
         # Bootloader related
-        deviceinfo_flash_method=\"""" + flash_method + """\"
+        deviceinfo_flash_method="{flash_method}"
         """
 
     content_heimdall_bootimg = """\
@@ -181,7 +191,7 @@ def generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
     # Write to file
     pmb.helpers.run.user(args, ["mkdir", "-p", args.work + "/aportgen"])
     with open(args.work + "/aportgen/deviceinfo", "w", encoding="utf-8") as handle:
-        for line in content.split("\n"):
+        for line in content.rstrip().split("\n"):
             handle.write(line.lstrip() + "\n")
 
 
@@ -192,40 +202,38 @@ def generate_apkbuild(args, pkgname, name, arch, flash_method):
         depends += " mkbootimg"
     if flash_method == "0xffff":
         depends += " uboot-tools"
-    depends += " mesa-dri-swrast"
+    depends += " mesa-dri-gallium"
 
     # Whole APKBUILD
-    content = """\
-        # Contributor: Firstname Lastname <email> (CHANGEME!)
-        # Maintainer: Firstname Lastname <email> (CHANGEME!)
+    content = f"""\
         # Reference: <https://postmarketos.org/devicepkg>
-        pkgname=\"""" + pkgname + """\"
-        pkgdesc=\"""" + name + """\"
+        pkgname={pkgname}
+        pkgdesc="{name}"
         pkgver=0.1
         pkgrel=0
         url="https://postmarketos.org"
         license="MIT"
-        arch=\"""" + arch + """\"
+        arch="{arch}"
         options="!check !archcheck"
-        depends=\"""" + depends + """\"
+        depends="{depends}"
         makedepends="devicepkg-dev"
         source="deviceinfo"
 
-        build() {
+        build() {{
             devicepkg_build $startdir $pkgname
-        }
+        }}
 
-        package() {
+        package() {{
             devicepkg_package $startdir $pkgname
-        }
+        }}
 
-        sha512sums="(run 'pmbootstrap checksum """ + pkgname + """' to fill)"
+        sha512sums="(run 'pmbootstrap checksum {pkgname}' to fill)"
         """
 
     # Write the file
     pmb.helpers.run.user(args, ["mkdir", "-p", args.work + "/aportgen"])
     with open(args.work + "/aportgen/APKBUILD", "w", encoding="utf-8") as handle:
-        for line in content.split("\n"):
+        for line in content.rstrip().split("\n"):
             handle.write(line[8:].replace(" " * 4, "\t") + "\n")
 
 
@@ -234,6 +242,7 @@ def generate(args, pkgname):
     manufacturer = ask_for_manufacturer(args)
     name = ask_for_name(args, manufacturer)
     year = ask_for_year(args)
+    chassis = ask_for_chassis(args)
     has_keyboard = ask_for_keyboard(args)
     has_external_storage = ask_for_external_storage(args)
     flash_method = ask_for_flash_method(args)
@@ -242,6 +251,6 @@ def generate(args, pkgname):
         bootimg = ask_for_bootimg(args)
 
     generate_deviceinfo(args, pkgname, name, manufacturer, year, arch,
-                        has_keyboard, has_external_storage,
+                        chassis, has_keyboard, has_external_storage,
                         flash_method, bootimg)
     generate_apkbuild(args, pkgname, name, arch, flash_method)
