@@ -14,7 +14,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.21.0"
+version = "1.22.2"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -45,6 +45,7 @@ config_keys = ["aports",
                "device",
                "extra_packages",
                "hostname",
+               "build_pkgs_on_install",
                "is_default_channel",
                "jobs",
                "kernel",
@@ -72,6 +73,7 @@ defaults = {
     "extra_packages": "none",
     "fork_alpine": False,
     "hostname": "",
+    "build_pkgs_on_install": True,
     # A higher value is typically desired, but this can lead to VERY long open
     # times on slower devices due to host systems being MUCH faster than the
     # target device (see issue #429).
@@ -80,7 +82,7 @@ defaults = {
     "kernel": "stable",
     "keymap": "",
     "log": "$WORK/log.txt",
-    "mirror_alpine": "http://dl-cdn.alpinelinux.org/alpine/",
+    "mirror_alpine": "http://dl-2.alpinelinux.org/alpine/",
     "mirrors_postmarketos": ["http://postmarketos1.brixit.nl/postmarketos/"],
     "nonfree_firmware": True,
     "nonfree_userland": False,
@@ -203,6 +205,7 @@ necessary_kconfig_options = {
     ">=4.0.0": {
         "all": {
             "UEVENT_HELPER": True,
+            "USER_NS": True,
         },
     },
     "<5.2.0": {
@@ -247,6 +250,13 @@ apkbuild_package_attributes = {
     "pkgdesc": {},
     "depends": {"array": True},
     "provides": {"array": True},
+
+    # UI meta-packages can specify apps in "_pmb_recommends" to be explicitly
+    # installed by default, and not implicitly as dependency of the UI meta-
+    # package ("depends"). This makes these apps uninstallable, without
+    # removing the meta-package. (#1933). To disable this feature, use:
+    # "pmbootstrap install --no-recommends".
+    "_pmb_recommends": {"array": True},
 }
 
 # Variables in APKBUILD files, that get parsed
