@@ -101,6 +101,36 @@ def get_kernel_package(args, device):
     return ["device-" + device + "-kernel-" + args.kernel]
 
 
+def get_recommends_packages(args):
+    """ Get all packages listed in _pmb_recommends of the UI and UI-extras
+        package, unless running with pmbootstrap install --no-recommends.
+
+        :returns: list of pkgnames, e.g. ["chatty", "gnome-contacts"] """
+    ret = []
+    if not args.install_recommends or args.ui == "none":
+        return ret
+
+    # UI package
+    meta = f"postmarketos-ui-{args.ui}"
+    apkbuild = pmb.helpers.pmaports.get(args, meta)
+    recommends = apkbuild["_pmb_recommends"]
+    if recommends:
+        logging.debug(f"{meta}: install _pmb_recommends:"
+                      f" {', '.join(recommends)}")
+        ret += recommends
+
+    # UI-extras subpackage
+    meta_extras = f"{meta}-extras"
+    if args.ui_extras and meta_extras in apkbuild["subpackages"]:
+        recommends = apkbuild["subpackages"][meta_extras]["_pmb_recommends"]
+        if recommends:
+            logging.debug(f"{meta_extras}: install _pmb_recommends:"
+                          f" {', '.join(recommends)}")
+            ret += recommends
+
+    return ret
+
+
 def copy_files_from_chroot(args, suffix):
     """
     Copy all files from the rootfs chroot to /mnt/install, except
@@ -154,12 +184,20 @@ def create_home_from_skel(args):
 
 def configure_apk(args):
     """
-    Copies over all keys used locally to compile packages, and disables the
-    /mnt/pmbootstrap-packages repository.
+    Copy over all official keys, and the keys used to compile local packages
+    (unless --no-local-pkgs is set). Then disable the /mnt/pmbootstrap-packages
+    repository.
     """
+    # Official keys
+    pattern = f"{pmb.config.apk_keys_path}/*.pub"
+
+    # Official keys + local keys
+    if args.install_local_pkgs:
+        pattern = f"{args.work}/config_apk_keys/*.pub"
+
     # Copy over keys
     rootfs = args.work + "/chroot_native/mnt/install"
-    for key in glob.glob(args.work + "/config_apk_keys/*.pub"):
+    for key in glob.glob(pattern):
         pmb.helpers.run.root(args, ["cp", key, rootfs + "/etc/apk/keys/"])
 
     # Disable pmbootstrap repository
@@ -597,7 +635,8 @@ def install(args):
     install_packages = (pmb.config.install_device_packages +
                         ["device-" + args.device] +
                         get_kernel_package(args, args.device) +
-                        get_nonfree_packages(args, args.device))
+                        get_nonfree_packages(args, args.device) +
+                        get_recommends_packages(args))
     if not args.install_base:
         install_packages = [p for p in install_packages if p != "postmarketos-base"]
     if args.ui.lower() != "none":
@@ -616,8 +655,9 @@ def install(args):
         install_packages += args.extra_packages.split(",")
     if args.add:
         install_packages += args.add.split(",")
-    for pkgname in install_packages:
-        pmb.build.package(args, pkgname, args.deviceinfo["arch"])
+    if args.build_pkgs_on_install:
+        for pkgname in install_packages:
+            pmb.build.package(args, pkgname, args.deviceinfo["arch"])
 
     # Install all packages to device rootfs chroot (and rebuild the initramfs,
     # because that doesn't always happen automatically yet, e.g. when the user
