@@ -16,7 +16,8 @@ import pmb.helpers.logging
 @pytest.fixture
 def args(tmpdir, request):
     import pmb.parse
-    sys.argv = ["pmbootstrap.py", "init"]
+    cfg = f"{pmb_test.const.testdata}/channels.cfg"
+    sys.argv = ["pmbootstrap.py", "--config-channels", cfg, "init"]
     args = pmb.parse.arguments()
     args.log = args.work + "/log_testsuite.txt"
     pmb.helpers.logging.init(args)
@@ -214,8 +215,25 @@ def test_questions_keymaps(args, monkeypatch):
 
 
 def test_questions_ui(args, monkeypatch):
+    args.aports = pmb_test.const.testdata + "/init_questions_device/aports"
+    device = "lg-mako"
+
+    fake_answers(monkeypatch, ["none"])
+    assert pmb.config.init.ask_for_ui(args, device) == "none"
+
     fake_answers(monkeypatch, ["invalid_UI", "weston"])
-    assert pmb.config.init.ask_for_ui(args) == "weston"
+    assert pmb.config.init.ask_for_ui(args, device) == "weston"
+
+
+def test_questions_ui_extras(args, monkeypatch):
+    args.aports = pmb_test.const.testdata + "/init_questions_device/aports"
+    assert not pmb.config.init.ask_for_ui_extras(args, "none")
+
+    fake_answers(monkeypatch, ["n"])
+    assert not pmb.config.init.ask_for_ui_extras(args, "weston")
+
+    fake_answers(monkeypatch, ["y"])
+    assert pmb.config.init.ask_for_ui_extras(args, "weston")
 
 
 def test_questions_work_path(args, monkeypatch, tmpdir):
@@ -232,8 +250,8 @@ def test_questions_work_path(args, monkeypatch, tmpdir):
     assert func(args) == (work, False)
 
 
-def test_questions_build_options(args, monkeypatch):
-    func = pmb.config.init.ask_for_build_options
+def test_questions_additional_options(args, monkeypatch):
+    func = pmb.config.init.ask_for_additional_options
     cfg = {"pmbootstrap": {}}
 
     # Skip changing anything
@@ -242,9 +260,10 @@ def test_questions_build_options(args, monkeypatch):
     assert cfg == {"pmbootstrap": {}}
 
     # Answer everything
-    fake_answers(monkeypatch, ["y", "5", "2G", "n"])
+    fake_answers(monkeypatch, ["y", "64", "5", "2G", "n"])
     func(args, cfg)
-    assert cfg == {"pmbootstrap": {"jobs": "5",
+    assert cfg == {"pmbootstrap": {"boot_size": "64",
+                                   "jobs": "5",
                                    "ccache_size": "2G"}}
 
 
@@ -271,3 +290,8 @@ def test_questions_hostname(args, monkeypatch):
     # Device name: empty string
     fake_answers(monkeypatch, [device])
     assert func(args, device) == ""
+
+
+def test_questions_channel(args, monkeypatch):
+    fake_answers(monkeypatch, ["invalid-channel", "stable"])
+    assert pmb.config.init.ask_for_channel(args) == "stable"
